summaryrefslogtreecommitdiff
path: root/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tests')
-rw-r--r--tests/Enum_Interfaces_Test.cpp15
1 files changed, 8 insertions, 7 deletions
diff --git a/tests/Enum_Interfaces_Test.cpp b/tests/Enum_Interfaces_Test.cpp
index 4be7b992129..8f569436b04 100644
--- a/tests/Enum_Interfaces_Test.cpp
+++ b/tests/Enum_Interfaces_Test.cpp
@@ -10,10 +10,11 @@
// Enum_interfaces.cpp
//
// = DESCRIPTION
// This is a simple test of <ACE::get_ip_interfaces>. This call
// retrieves the IP addresses assigned to the host by
// interrogating the kernel. Network applications typically
// assume gethostbyname(uname()) will work, but this is just a
// convention. It is also problematic if the resolver code
// (DNS/NIS+...) is misconfigured. This happens more than
// programmers realize. It is better to find out by asking the
@@ -48,12 +49,12 @@ ACE_TMAIN (int, ACE_TCHAR *[])
ACE_INET_Addr *the_addr_array;
size_t how_many = 0;
- int rc = ACE::get_ip_interfaces (how_many, the_addr_array);
+ int rc = ACE_Sock_Connect::get_ip_interfaces (how_many, the_addr_array);
if (rc != 0)
ACE_ERROR ((LM_ERROR,
ACE_TEXT ("%p\n"),
- ACE_TEXT ("ACE::get_ip_interfaces failed")));
+ ACE_TEXT ("ACE_Sock_Connect::get_ip_interfaces failed")));
else if (how_many == 0)
ACE_ERROR ((LM_ERROR,
ACE_TEXT ("No interfaces presently configured in the kernel\n")));
@@ -68,6 +69,6 @@ ACE_TMAIN (int, ACE_TCHAR *[])
}
ACE_END_TEST;
- return rc != 0; // return 1 if get_ip_interfaces failed
+ return rc != 0; // return 1 if get_ip_interfaces() failed
}
@@ -10,10 +10,11 @@
//
// = DESCRIPTION
-// This is a simple test of <ACE::get_ip_interfaces>. This call
-// retrieves the IP addresses assigned to the host by
-// interrogating the kernel. Network applications typically
-// assume gethostbyname(uname()) will work, but this is just a
+// This is a simple test of
+// <ACE_Sock_Connection::get_ip_interfaces>. This call retrieves
+// the IP addresses assigned to the host by interrogating the
+// kernel. Network applications typically assume
+// gethostbyname(uname()) will work, but this is just a
// convention. It is also problematic if the resolver code
// (DNS/NIS+...) is misconfigured. This happens more than